@@ -24,7 +24,7 @@ class articles(base):
         data = {}
         data["articleId"] = articleId
         data["page"] = page
-        data["rows"] = rows
+        data["rows"] = row
         return self.request(api_name, data)
 
     def addPraiseNum(self, articleId):
