@@ -7,6 +7,7 @@
 '''
 import requests
 import json
+from loguru import logger
 
 
 def request_accesstoken(acc: str, pwd: str, safe=False, domain=True, **kwargs) -> str:
@@ -31,8 +32,7 @@ class base:
         self.app_secret = app_secret
 
     def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
-        # host_name = "http://bms.microc.cn/shopguide/api/"
-        # host_name = "http://test.xxynet.com/shopguide/api/"
+
         protocol = "https" if safe else "http"
         domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
@@ -76,8 +76,7 @@ class baseApi:
         self.app_secret = app_secret
 
     def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
-        # host_name = "http://bms.microc.cn/shopguide/api/"
-        # host_name = "http://test.xxynet.com/shopguide/api/"
+
         protocol = "https" if safe else "http"
         domain_name = "api.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
@@ -120,8 +119,7 @@ class baseSub:
         self.app_secret = app_secret
 
     def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
-        # host_name = "http://bms.microc.cn/shopguide/api/"
-        # host_name = "http://test.xxynet.com/shopguide/api/"
+
         protocol = "https" if safe else "http"
         domain_name = "sub.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
@@ -164,8 +162,7 @@ class baseCient:
         self.app_secret = app_secret
 
     def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=True, **kwargs):
-        # host_name = "http://bms.microc.cn/shopguide/api/"
-        # host_name = "http://test.xxynet.com/shopguide/api/"
+
         protocol = "https" if safe else "http"
         domain_name = "cient.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/api/"
@@ -200,3 +197,89 @@ class baseCient:
 
     def response(self, response_raw):
         return response_raw
+
+
+class baseApixxYent:
+    def __init__(self, token, app_secret=None):
+        self.token = token
+        self.app_secret = app_secret
+
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None,domain=True, **kwargs):
+        domain_name = "api.xxynet.com" if domain else "it.xxynet.com"
+        host_name = f"https://{domain_name}/"
+        if not url:
+            if host_name not in api_name:
+                url = f"{host_name}{api_name}"
+                logger.debug(url)
+        condition = {}
+
+        if "accessToken" not in params:
+            # 没有token自动添加
+            params["accessToken"] = self.token
+        if "appSecret" not in params:
+            # 没有token自动添加
+            params["appSecret"] = self.app_secret
+        if params:
+            condition["params"] = params
+        if data:
+            condition["data"] = data
+        if json:
+            condition["json"] = json
+        if headers:
+            condition["headers"] = headers
+
+        if method == "GET":
+            response = requests.get(url, **condition, timeout=10)
+        elif method == "POST":
+            response = requests.post(url, **condition, timeout=10)
+        else:
+            raise ValueError("请求方法错误。")
+        if response.status_code == 200:
+            return self.response(response.json())
+
+    def response(self, response_raw):
+        return response_raw
+
+
+class baseQuestion:
+    def __init__(self, token, app_secret=None):
+        self.token = token
+        self.app_secret = app_secret
+
+    def request(self, api_name=None, params={}, data={}, json={}, headers={}, method="GET", url=None, safe=False, domain=False, **kwargs):
+
+        protocol = "https" if safe else "http"
+        domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
+        host_name = f"{protocol}://{domain_name}/shopguide-question/api/"
+        if not url:
+            if host_name not in api_name:
+                url = f"{host_name}{api_name}"
+
+        condition = {}
+
+        if "accessToken" not in params:
+            # 没有token自动添加
+            params["accessToken"] = self.token
+        if "appSecret" not in params:
+            # 没有token自动添加
+            params["appSecret"] = self.app_secret
+        if params:
+            condition["params"] = params
+        if data:
+            condition["data"] = data
+        if json:
+            condition["json"] = json
+        if headers:
+            condition["headers"] = headers
+
+        if method == "GET":
+            response = requests.get(url, **condition, timeout=10)
+        elif method == "POST":
+            response = requests.post(url, **condition, timeout=10)
+        else:
+            raise ValueError("请求方法错误。")
+        if response.status_code == 200:
+            return self.response(response.json())
+
+    def response(self, response_raw):
+        return response_raw
